client

package
v0.0.0-...-4396a18 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 26, 2025 License: MPL-2.0 Imports: 7 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type AuthServiceClient

type AuthServiceClient struct {
	// contains filtered or unexported fields
}

AuthServiceClient manages the gRPC client for auth service

func NewAuthServiceClient

func NewAuthServiceClient(cfg config.AuthServiceConfig) (*AuthServiceClient, error)

NewAuthServiceClient creates a new auth service client with configuration

func (*AuthServiceClient) Close

func (c *AuthServiceClient) Close() error

Close closes the gRPC connection

func (*AuthServiceClient) GetClient

GetClient returns the underlying gRPC client

func (*AuthServiceClient) GetUserServiceClient

func (c *AuthServiceClient) GetUserServiceClient() userpb.UserServiceClient

GetUserServiceClient returns a user service client using the same connection

Jump to