Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type AuthServiceClient ¶
type AuthServiceClient struct {
// contains filtered or unexported fields
}
AuthServiceClient manages the gRPC client for auth service
func NewAuthServiceClient ¶
func NewAuthServiceClient(cfg config.AuthServiceConfig) (*AuthServiceClient, error)
NewAuthServiceClient creates a new auth service client with configuration
func (*AuthServiceClient) Close ¶
func (c *AuthServiceClient) Close() error
Close closes the gRPC connection
func (*AuthServiceClient) GetClient ¶
func (c *AuthServiceClient) GetClient() userpb.AuthServiceClient
GetClient returns the underlying gRPC client
func (*AuthServiceClient) GetUserServiceClient ¶
func (c *AuthServiceClient) GetUserServiceClient() userpb.UserServiceClient
GetUserServiceClient returns a user service client using the same connection
Click to show internal directories.
Click to hide internal directories.